def compute_peakness(losses):
    """Compute the peak value of the losses."""
    return max(losses) if losses else float('nan')

def compute_inflection_point(losses):
    """Compute the inflection point of the loss curve."""
    if not losses:
        return -1
    for i in range(1, len(losses) - 1):
        if losses[i] < losses[i - 1] and losses[i] < losses[i + 1]:
            return i
    return -1

def compute_area_of_inflection(losses):
    """Compute the area under the losses curve."""
    return sum(losses) if losses else float('nan')

def compute_length_of_inflection(losses):
    """Compute the length between the first and last minimum points."""
    first_min, last_min = None, None
    if not losses:
        return 0
    for i in range(1, len(losses) - 1):
        if losses[i] < losses[i - 1] and losses[i] < losses[i + 1]:
            if first_min is None:
                first_min = i
            last_min = i
    if first_min is None or last_min is None:
        return 0
    return last_min - first_min
