# CycleResearcher: Improving Automated Research via Automated Review



  ![](img/method.png)

## 🎯 Introduction

CycleResearcher is a groundbreaking open-source project aimed at improving automated research through automated review. Our system comprises two core models: CycleResearcher and CycleReviewer, working in tandem to simulate the complete research and review cycle.

Our objectives are:
- 🤖 Automate academic research processes

- 📝 Provide high-quality research reviews

- 🔄 Establish research-review feedback loops

- 🚀 Accelerate scientific discovery

  

## 🚀 Getting Started

`pip install -e .`

### 📚 Tutorials and Demos

We have prepared comprehensive tutorials for both CycleResearcher and CycleReviewer to help users better understand and utilize these models. Our tutorials cover everything you need to get started and make the most of our model suite.

##### Available Tutorials
- [Tutorial 1:]() Getting Started with CycleResearcher 🚀
- [Tutorial 2:]() Understanding CycleReviewer 📝
- [Tutorial 3:]() Advanced Features🔥 Rejection Sampling with CycleResearcher and CycleReviewer [TODO]
- [Tutorial 4](): Using CycleResearcher as a Thinker to Achieve Fully Automated Scientific Discovery



### 🔄 Review-5K and Research-14K datasets

  ![](img/dataset.png)

## 📈 Model Evaluation

#### CycleReviewer

  <img src="img/cyclereviewer.png"  />

Comparison of automated models on generating peer review including various API-based methods and ours. CycleReviewer clearly outperforms both proprietary systems and human experts in peer review tasks. Specifically, it achieves a 48.77\% reduction in Proxy MSE and a 26.89\% reduction in Proxy MAE compared to human reviewers. With a decision accuracy of 74.24\%, our model demonstrates a significant lead over other closed-source systems.

#### CycleResearcher

![.img/cycleresearcher.png](/img/cycleresearcher.png)

CycleResearcher-12B achieves an average score of 5.36, approaching the 5.69 average scores for conference-accepted papers and surpassing AI Scientist's score of 4.31.

## 🔍 Model Detection

```
from cycleresearcher.detect import FastDetectGPT
detector = FastDetectGPT(
    model_name="meta-llama/Llama-3.1-8B",
    reference_model_name=None, 
    device="cuda"
)


text = "paper..."
result = detector.detect(text)
print(f"Criterion: {result['criterion']:.4f}")
print(f"Probability of being machine-generated: {result['probability']*100:.0f}%")

# BATCH
texts = ["Paper 1...", "Paper 2...", "Paper 3..."]
results = detector.detect_batch(texts)
```


